@@ -1,6 +1,6 @@
 package Lingua::Identify::CLD;
 
-use 5.006;
+use 5.008;
 use strict;
 use warnings;
 
@@ -11,11 +11,11 @@ Lingua::Identify::CLD - Interface to Chrome language detection library.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use XSLoader;
 BEGIN {
@@ -26,15 +26,35 @@ BEGIN {
 
     use Lingua::Identify::CLD;
 
+    # Vanilla identification
     my $cld = Lingua::Identify::CLD->new();
-
     my $lang = $cld->identify("Text");
 
+    # using TLD hint
+    my $lang = $cld->identify("Text", tld => 'by');
+
+    # CLD object can also be created with this option
+    my $bycld = Lingua::Identify::CLD->new(tld => 'by');
+
 =head1 METHODS
 
 =head2 new
 
-Constructs a CLD object.
+Constructs a CLD object. You can pass some global configuration
+options. Currently supported options are listed bellow:
+
+=over 4
+
+=item tld
+
+A top level domain (tld) to help on the language identification.
+
+=item isPlainText
+
+By default is set to true. If you have some HTML/XML markup, set it to
+false.
+
+=back
 
 =cut
 
@@ -46,14 +66,23 @@ sub new {
 
 =head2 identify
 
-Receives a string, returns a language name.
+Receives a string, returns a language name. Following the text a set
+of key/value options may be supplied. The supported options are the
+same as of C<new>.
 
 =cut
 
 sub identify {
     my ($self, $text, %options) = @_;
 
-    return _identify($text);
+    my %cfg = ( %$self, %options );
+
+    my $tld       = exists($cfg{tld})         ? $cfg{tld}         : "";
+    my $plaintext = exists($cfg{isPlainText}) ? $cfg{isPlainText} : 1;
+
+    my $lang = _identify($text, $tld, $plaintext);
+
+    return uc $lang;
 }
 
 =head1 AUTHOR
